@@ -1,22 +1,20 @@
 # Cuts a vector into separate groups according to input breaks
-#' @importFrom methods is
 cutGMM <- function(x, breaks, right = TRUE) {
-  sizeX <- function(A) {
-    TA <- is(A)
-    TypeOfA <- TA[2]
-    Result <- c(NaN, NaN)
-    if (TypeOfA == "vector") {
-      Result <- c(length(A), 1)
-    }
-    if (TypeOfA == "array") {
-      Result <- dim(A)
-    }
-    return(Result)
+
+   DIM <- function(...) {
+    args <- list(...)
+    unlist(lapply(args, function(x) {
+      if (is.null(dim(x))) {
+        return(1)
+      }
+      dim(x)[2]
+    }))
   }
 
-  if (sizeX(x)[2] > 1 | length(x) == 0)
-    stop("CutGMM: x should be a single vector of length > 0.")
-  if (length(breaks) > 0) {
+    if (DIM(x) != 1 | is.numeric(x) == FALSE | length(x) == 0)
+     stop("CutGMM: x should be a single numerical vector of length > 0.")
+
+   if (length(breaks) > 0) {
     if (hasArg(right) == FALSE) {
       right <- TRUE
     }
@@ -35,7 +33,6 @@ cutGMM <- function(x, breaks, right = TRUE) {
   } else {
     warning("cutGMM: No breaks provided. Assuming one single class.", call. = FALSE)
   }
-
   # Return results
   return(ClassesGMM)
 }
